#ifndef XCOIN_H
#define XCOIN_H

#ifdef __cplusplus
extern "C" {
#endif

void drk_hash(const char* input, char* output);

#ifdef __cplusplus
}
#endif

#endif
